==> typst-lsp-0.7.2.tar.gz: typst-lsp-0.7.2/.github/ISSUE_TEMPLATE/bug_report.md <==
---
name: "🐞 Bug Report"
about: Did you find a bug?
title: ''
assignees: ''

---

<!--
    Hi there! Thank you for submitting a bug report!

    Please fill out the template below; insufficient information or bad reproduction instructions will impair the
    ability of others to help you.
-->

<!-- All the below information must be provided for others to understand and help with your issue. -->
- **Component**: <!-- Indicate which is appropriate. Checked checkbox should look like this: [x] -->
    - [ ] VSCode Extension
    - [ ] VSCodium Extension
    - [ ] LSP (used with other editor)
- **Extension version**: <!-- Replace with version of the Typst LSP extension -->
- **LSP version**: <!-- Replace with version of the typst-lsp binary -->
- **OS version and name**: <!-- Replace with version + name, e.g. Ubuntu 22.04 or macOS 12.6 -->

<!-- All the below steps should be completed before submitting your issue. Checked checkbox should look like this: [x] -->
- [ ] I am on the [latest](https://github.com/nvarner/typst-lsp/tags) stable version of the extension/LSP.
- [ ] I have searched the [issues](https://github.com/nvarner/typst-lsp/issues) of this repo and believe that this is not a duplicate.

## Issue
<!--
    Now feel free to write your issue, and please be as descriptive as possible! Make sure to include detailed
    reproduction steps, but keep the examples minimal.
-->


### Logs
<!--
    If applicable.
    In VSCode/VSCodium, open the "Output" panel (ctrl+shift+U or cmd+shift+U) and select "Typst Language Server" from
    the dropdown on the right. Then copy-paste the contents of the logs below.
-->

```
Include any logs if relevant, otherwise remove this code block.
```

<!-- Thanks again 🙌 ❤ -->

==> typst-lsp-0.9.1.tar.gz: typst-lsp-0.9.1/.github/ISSUE_TEMPLATE/bug_report.md <==
---
name: "🐞 Bug Report"
about: Did you find a bug?
title: ''
assignees: ''

---

<!--
    Hi there! Thank you for submitting a bug report!

    Please fill out the template below; insufficient information or bad reproduction instructions will impair the
    ability of others to help you.
-->

<!-- All the below information must be provided for others to understand and help with your issue. -->
- **Component**: <!-- Include the relevant component(s). Delete the rest. -->
    - VSCode Extension
    - LSP (used with other editor)
- **Extension version**: <!-- Replace with version of the Typst LSP extension -->
- **LSP version**: <!-- Replace with version of the typst-lsp binary -->
- **OS version and name**: <!-- Replace with version + name, e.g. Ubuntu 22.04 or macOS 12.6 -->

<!-- All the below steps should be completed before submitting your issue. -->
- I am on the [latest](https://github.com/nvarner/typst-lsp/tags) stable version of the extension/LSP.
- I have searched the [issues](https://github.com/nvarner/typst-lsp/issues) of this repo and believe that this is not a duplicate.

## Issue
<!--
    Now feel free to write your issue, and please be as descriptive as possible! Make sure to include detailed
    reproduction steps, but keep the examples minimal.
-->


### Logs
<!--
    If applicable.
    In VSCode/VSCodium, open the "Output" panel (ctrl+shift+U or cmd+shift+U) and select "Typst Language Server" from
    the dropdown on the right. Then copy-paste the contents of the logs below.
-->

```
Include any logs if relevant, otherwise remove this code block.
```

<!-- Thanks again 🙌 ❤ -->
